C  ***************************
C  ***************************
C  *** UNTERPROGRAMM SPA93 ***
C  ***************************
C  ***************************
C  DAS UNTERPROGRAMM SPA93 ERMITTELT DIE KRAEFTE UND
C  MOMENTE AN RAEUMLICHEN BALKENELEMENTEN SOWIE DIE
C  LOKALEN VERDREHUNGEN UND DRUCKT SIE
C*******************************************************
C*   VERWENDETE VARIABLEN                              *
C*                                                     *
C*   I1      : ELEMENTNUMMER                           *
C*   E       : ELASTIZITAETSMODUL                      *
C*   AR      : QUERSCHNITTSFLAECHE                     *
C*   Q       : QUERKONTRAKTIONSZAHL                    *
C*   TRZ;TRY : FLAECHENTRAEGHEITSMOMENTE BEZUEGLICH    *
C*             DER LOKALEN ACHSEN                      *
C*   TRTO    : TORSIONSTRAEGHEITSMOMENT                *
C*   XL-ZL   : ACHSENABSCHNITTE                        *
C*   BL      : LAENGE DES BALKENELEMENTES              *
C*                                                     *
C*   VERWENDETE FELDER                                 *
C*                                                     *
C*   X       : KNOTENKOORDINATEN                       *
C*   I4      : BETEILIGTE KNOTENNUMMERN                *
C*   FV      : TEIL DER LOKALEN ES-MATRIX              *
C*   F       : KRAFTVEKTOR                             *
C*   D3      : TRANSFORMATIONSMATRIX                   *
C*   VLOK    : VEKTOR DER LOKALEN VERSCHIEBUNGEN       *
C*******************************************************
      SUBROUTINE SPA93 (I1,I4,X,L1,E,AR,Q,TRZ,TRY,TRTO)
      IMPLICIT REAL*8 (A-H,O-Z)
      INTEGER       FREI, ANZA
      DIMENSION     X(3,3),FV(6,12),F(12),I4(3),D3(3,3),VLOK(12)
      COMMON /FELD/ A(110),D(6105),V(500),XKN(500)
      COMMON /PAR/  KOANZ,FREI,ANZA,ETYP(2),MBAND,LELE,
     *              LREF,LRAN,KGRNR,LGS,LAD,LAV,LAX
C
C        INITIALISIEREN
C
      DO   5  J= 1,12
      F(J) = 0.
      VLOK(J)=0.
      DO   5  K= 1, 6
5     FV(K,J)= 0.
C
C        ERMITTELN DER TRANSFORMATIONSMATRIX
C
      XL = X(2,1)-X(1,1)
      YL = X(2,2)-X(1,2)
      ZL = X(2,3)-X(1,3)
C
      BL = (XL**2+YL**2+ZL**2)**0.5
C
      D3(1,1) = XL/BL
      D3(1,2) = YL/BL
      D3(1,3) = ZL/BL
C
      BLS = (D3(1,1)**2+D3(1,2)**2)**0.5
C
C          SONDERFALL BALKEN IN Z- RICHTUNG
C
      IF(BLS.NE.0.) GOTO 10
      D3(2,1)=0.
      D3(2,2)=1.
      GOTO 20
10    D3(2,1) =-D3(1,2)/BLS
      D3(2,2) = D3(1,1)/BLS
20    D3(2,3) = 0.
      D3(3,1) = D3(1,2)*D3(2,3)-D3(1,3)*D3(2,2)
      D3(3,2) = D3(1,3)*D3(2,1)-D3(2,3)*D3(1,1)
      D3(3,3) = D3(1,1)*D3(2,2)-D3(1,2)*D3(2,1)
C
C          ERMITTLUNG DER LOKALEN VERSCHIEBUNGEN
C
      DO  30  K=1,2
      DO  30  L=1,3
      DO  30  M=1,3
      K1 = 3*(K-1)+L
      N1 =(I4(1)-1)*FREI+3*(K-1)+M
      N2 =(I4(2)-1)*FREI+3*(K-1)+M
      VLOK(K1) = VLOK(K1)+D3(L,M)*V(N1)
30    VLOK(K1+6) = VLOK(K1+6)+D3(L,M)*V(N2)
C
      EL = E/BL**2
      GL = E/(2*(1+Q))
C
C       AUFSTELLUNG DER LOKALEN ES-MATRIX
C
      FV( 1, 1) = EL*AR*BL
      FV( 1, 7) =-FV( 1, 1)
      FV( 2, 2) = 12.*EL*TRZ/BL
      FV( 2, 8) =-FV( 2, 2)
      FV( 2, 6) = 6.*EL*TRZ
      FV( 2,12) = FV( 2, 6)
      FV( 6, 2) = FV( 2,12)
      FV( 6, 8) =-FV( 2,12)
      FV( 3, 3) = 12.*EL*TRY/BL
      FV( 3, 9) =-FV( 3, 3)
      FV( 3, 5) =-6.*EL*TRY
      FV( 3,11) = FV( 3, 5)
      FV( 5, 3) = FV( 3, 5)
      FV( 5, 9) =-FV( 3, 5)
      FV( 4, 4) = GL*TRTO/BL
      FV( 4,10) =-FV( 4, 4)
      FV( 5, 5) = 4.*EL*TRY*BL
      FV( 5,11) = FV( 5, 5)/2.
      FV( 6, 6) = 4.*EL*TRZ*BL
      FV( 6,12) = FV( 6, 6)/2.
C
C       ERMITTLUNG DES KRAFTVEKTORS
C
      DO  40  K =1, 6
      DO  40  L =1,12
40    F(K) = F(K)+VLOK(L)*FV(K,L)
C
      DO  50  K =1, 4
50    F(K+6) =-F(K)
C
      F(11) = F(5)-(VLOK(5)*FV(5,5)+VLOK(11)*FV(5,11))
     *            +(VLOK(5)*FV(5,11)+VLOK(11)*FV(5,5))
C
      F(12) = F(6)-(VLOK(6)*FV(6,6)+VLOK(12)*FV(6,12))
     *            +(VLOK(6)*FV(6,12)+VLOK(12)*FV(6,6))
C
C       DRUCKEN DER UEBERSCHRIFT
C
      IF(L1.EQ.1)  WRITE (6,55)
55    FORMAT (26X,'LOKALE KRAEFTE,MOMENTE UND VERDREHUNGEN'//)
C
C       DRUCKEN DES KRAFTVEKTORS UND DER LOKALEN VERDREHUNGEN
C
      WRITE (6,60) I1,I4(1),(F(J),J=1,6),(VLOK(J),J=4,6),
     *             I4(2),(F(K),K=7,12),(VLOK(J),J=10,12)
60    FORMAT (1H ,I5,2(3X,I5,3X,'FLAENGS= ',E11.5,2X,
     *        'FQUERY = ',E11.5,2X,'FQUERZ = ',E11.5/17X,
     *        'MTORS  = ',E11.5,2X,'MBY    = ',E11.5,2X,
     *        'MBZ    = ',E11.5/17X,'WX     = ',E11.5,2X,
     *        'WY     = ',E11.5,2X,'WZ     = ',E11.5//6X))
C
      RETURN
      END
